==> aspose_barcode_cloud-0.23.6.tar.gz: lib/model/decode_barcode_type.dart <==
part of aspose_barcode_cloud.api;

class DecodeBarcodeType {
  DecodeBarcodeType._internal(this.value);

  DecodeBarcodeType.fromJson(dynamic data) {
    switch (data) {
      case "all":
        value = data;
        break;
      case "AustraliaPost":
        value = data;
        break;
      case "Aztec":
        value = data;
        break;
      case "ISBN":
        value = data;
        break;
      case "Codabar":
        value = data;
        break;
      case "Code11":
        value = data;
        break;
      case "Code128":
        value = data;
        break;
      case "GS1Code128":
        value = data;
        break;
      case "Code39Extended":
        value = data;
        break;
      case "Code39Standard":
        value = data;
        break;
      case "Code93Extended":
        value = data;
        break;
      case "Code93Standard":
        value = data;
        break;
      case "DataMatrix":
        value = data;
        break;
      case "DeutschePostIdentcode":
        value = data;
        break;
      case "DeutschePostLeitcode":
        value = data;
        break;
      case "EAN13":
        value = data;
        break;
      case "EAN14":
        value = data;
        break;
      case "EAN8":
        value = data;
        break;
      case "IATA2of5":
        value = data;
        break;
      case "Interleaved2of5":
        value = data;
        break;
      case "ISSN":
        value = data;
        break;
      case "ISMN":
        value = data;
        break;
      case "ItalianPost25":
        value = data;
        break;
      case "ITF14":
        value = data;
        break;
      case "ITF6":
        value = data;
        break;
      case "MacroPdf417":
        value = data;
        break;
      case "Matrix2of5":
        value = data;
        break;
      case "MSI":
        value = data;
        break;
      case "OneCode":
        value = data;
        break;
      case "OPC":
        value = data;
        break;
      case "PatchCode":
        value = data;
        break;
      case "Pdf417":
        value = data;
        break;
      case "MicroPdf417":
        value = data;
        break;
      case "Planet":
        value = data;
        break;
      case "Postnet":
        value = data;
        break;
      case "PZN":
        value = data;
        break;
      case "QR":
        value = data;
        break;
      case "MicroQR":
        value = data;
        break;
      case "RM4SCC":
        value = data;
        break;
      case "SCC14":
        value = data;
        break;
      case "SSCC18":
        value = data;
        break;
      case "Standard2of5":
        value = data;
        break;
      case "Supplement":
        value = data;
        break;
      case "UPCA":
        value = data;
        break;
      case "UPCE":
        value = data;
        break;
      case "VIN":
        value = data;
        break;
      case "Pharmacode":
        value = data;
        break;
      case "GS1DataMatrix":
        value = data;
        break;
      case "DatabarOmniDirectional":
        value = data;
        break;
      case "DatabarTruncated":
        value = data;
        break;
      case "DatabarLimited":
        value = data;
        break;
      case "DatabarExpanded":
        value = data;
        break;
      case "SwissPostParcel":
        value = data;
        break;
      case "AustralianPosteParcel":
        value = data;
        break;
      case "Code16K":
        value = data;
        break;
      case "DatabarStackedOmniDirectional":
        value = data;
        break;
      case "DatabarStacked":
        value = data;
        break;
      case "DatabarExpandedStacked":
        value = data;
        break;
      case "CompactPdf417":
        value = data;
        break;
      case "GS1QR":
        value = data;
        break;
      case "MaxiCode":
        value = data;
        break;
      case "MicrE13B":
        value = data;
        break;
      case "Code32":
        value = data;
        break;
      case "DataLogic2of5":
        value = data;
        break;
      case "DotCode":
        value = data;
        break;
      case "DutchKIX":
        value = data;
        break;
      case "CodablockF":
        value = data;
        break;
      case "Mailmark":
        value = data;
        break;
      case "GS1DotCode":
        value = data;
        break;
      case "HIBCCode39LIC":
        value = data;
        break;
      case "HIBCCode128LIC":
        value = data;
        break;
      case "HIBCAztecLIC":
        value = data;
        break;
      case "HIBCDataMatrixLIC":
        value = data;
        break;
      case "HIBCQRLIC":
        value = data;
        break;
      case "HIBCCode39PAS":
        value = data;
        break;
      case "HIBCCode128PAS":
        value = data;
        break;
      case "HIBCAztecPAS":
        value = data;
        break;
      case "HIBCDataMatrixPAS":
        value = data;
        break;
      case "HIBCQRPAS":
        value = data;
        break;
      case "HanXin":
        value = data;
        break;
      case "GS1HanXin":
        value = data;
        break;
      default:
        throw Exception('Unknown enum value to decode: $data');
    }
  }

  /// The underlying value of this enum member.
  String? value;

  /// See DecodeType
  static DecodeBarcodeType all_ = DecodeBarcodeType._internal("all");

  /// See DecodeType
  static DecodeBarcodeType australiaPost_ =
      DecodeBarcodeType._internal("AustraliaPost");

  /// See DecodeType
  static DecodeBarcodeType aztec_ = DecodeBarcodeType._internal("Aztec");

  /// See DecodeType
  static DecodeBarcodeType iSBN_ = DecodeBarcodeType._internal("ISBN");

  /// See DecodeType
  static DecodeBarcodeType codabar_ = DecodeBarcodeType._internal("Codabar");

  /// See DecodeType
  static DecodeBarcodeType code11_ = DecodeBarcodeType._internal("Code11");

  /// See DecodeType
  static DecodeBarcodeType code128_ = DecodeBarcodeType._internal("Code128");

  /// See DecodeType
  static DecodeBarcodeType gS1Code128_ =
      DecodeBarcodeType._internal("GS1Code128");

  /// See DecodeType
  static DecodeBarcodeType code39Extended_ =
      DecodeBarcodeType._internal("Code39Extended");

  /// See DecodeType
  static DecodeBarcodeType code39Standard_ =
      DecodeBarcodeType._internal("Code39Standard");

  /// See DecodeType
  static DecodeBarcodeType code93Extended_ =
      DecodeBarcodeType._internal("Code93Extended");

  /// See DecodeType
  static DecodeBarcodeType code93Standard_ =
      DecodeBarcodeType._internal("Code93Standard");

  /// See DecodeType
  static DecodeBarcodeType dataMatrix_ =
      DecodeBarcodeType._internal("DataMatrix");

  /// See DecodeType
  static DecodeBarcodeType deutschePostIdentcode_ =
      DecodeBarcodeType._internal("DeutschePostIdentcode");

  /// See DecodeType
  static DecodeBarcodeType deutschePostLeitcode_ =
      DecodeBarcodeType._internal("DeutschePostLeitcode");

  /// See DecodeType
  static DecodeBarcodeType eAN13_ = DecodeBarcodeType._internal("EAN13");

  /// See DecodeType
  static DecodeBarcodeType eAN14_ = DecodeBarcodeType._internal("EAN14");

  /// See DecodeType
  static DecodeBarcodeType eAN8_ = DecodeBarcodeType._internal("EAN8");

  /// See DecodeType
  static DecodeBarcodeType iATA2of5_ = DecodeBarcodeType._internal("IATA2of5");

  /// See DecodeType
  static DecodeBarcodeType interleaved2of5_ =
      DecodeBarcodeType._internal("Interleaved2of5");

  /// See DecodeType
  static DecodeBarcodeType iSSN_ = DecodeBarcodeType._internal("ISSN");

  /// See DecodeType
  static DecodeBarcodeType iSMN_ = DecodeBarcodeType._internal("ISMN");

  /// See DecodeType
  static DecodeBarcodeType italianPost25_ =
      DecodeBarcodeType._internal("ItalianPost25");

  /// See DecodeType
  static DecodeBarcodeType iTF14_ = DecodeBarcodeType._internal("ITF14");

  /// See DecodeType
  static DecodeBarcodeType iTF6_ = DecodeBarcodeType._internal("ITF6");

  /// See DecodeType
  static DecodeBarcodeType macroPdf417_ =
      DecodeBarcodeType._internal("MacroPdf417");

  /// See DecodeType
  static DecodeBarcodeType matrix2of5_ =
      DecodeBarcodeType._internal("Matrix2of5");

  /// See DecodeType
  static DecodeBarcodeType mSI_ = DecodeBarcodeType._internal("MSI");

  /// See DecodeType
  static DecodeBarcodeType oneCode_ = DecodeBarcodeType._internal("OneCode");

  /// See DecodeType
  static DecodeBarcodeType oPC_ = DecodeBarcodeType._internal("OPC");

  /// See DecodeType
  static DecodeBarcodeType patchCode_ =
      DecodeBarcodeType._internal("PatchCode");

  /// See DecodeType
  static DecodeBarcodeType pdf417_ = DecodeBarcodeType._internal("Pdf417");

  /// See DecodeType
  static DecodeBarcodeType microPdf417_ =
      DecodeBarcodeType._internal("MicroPdf417");

  /// See DecodeType
  static DecodeBarcodeType planet_ = DecodeBarcodeType._internal("Planet");

  /// See DecodeType
  static DecodeBarcodeType postnet_ = DecodeBarcodeType._internal("Postnet");

  /// See DecodeType
  static DecodeBarcodeType pZN_ = DecodeBarcodeType._internal("PZN");

  /// See DecodeType
  static DecodeBarcodeType qR_ = DecodeBarcodeType._internal("QR");

  /// See DecodeType
  static DecodeBarcodeType microQR_ = DecodeBarcodeType._internal("MicroQR");

  /// See DecodeType
  static DecodeBarcodeType rM4SCC_ = DecodeBarcodeType._internal("RM4SCC");

  /// See DecodeType
  static DecodeBarcodeType sCC14_ = DecodeBarcodeType._internal("SCC14");

  /// See DecodeType
  static DecodeBarcodeType sSCC18_ = DecodeBarcodeType._internal("SSCC18");

  /// See DecodeType
  static DecodeBarcodeType standard2of5_ =
      DecodeBarcodeType._internal("Standard2of5");

  /// See DecodeType
  static DecodeBarcodeType supplement_ =
      DecodeBarcodeType._internal("Supplement");

  /// See DecodeType
  static DecodeBarcodeType uPCA_ = DecodeBarcodeType._internal("UPCA");

  /// See DecodeType
  static DecodeBarcodeType uPCE_ = DecodeBarcodeType._internal("UPCE");

  /// See DecodeType
  static DecodeBarcodeType vIN_ = DecodeBarcodeType._internal("VIN");

  /// See DecodeType
  static DecodeBarcodeType pharmacode_ =
      DecodeBarcodeType._internal("Pharmacode");

  /// See DecodeType
  static DecodeBarcodeType gS1DataMatrix_ =
      DecodeBarcodeType._internal("GS1DataMatrix");

  /// See DecodeType
  static DecodeBarcodeType databarOmniDirectional_ =
      DecodeBarcodeType._internal("DatabarOmniDirectional");

  /// See DecodeType
  static DecodeBarcodeType databarTruncated_ =
      DecodeBarcodeType._internal("DatabarTruncated");

  /// See DecodeType
  static DecodeBarcodeType databarLimited_ =
      DecodeBarcodeType._internal("DatabarLimited");

  /// See DecodeType
  static DecodeBarcodeType databarExpanded_ =
      DecodeBarcodeType._internal("DatabarExpanded");

  /// See DecodeType
  static DecodeBarcodeType swissPostParcel_ =
      DecodeBarcodeType._internal("SwissPostParcel");

  /// See DecodeType
  static DecodeBarcodeType australianPosteParcel_ =
      DecodeBarcodeType._internal("AustralianPosteParcel");

  /// See DecodeType
  static DecodeBarcodeType code16K_ = DecodeBarcodeType._internal("Code16K");

  /// See DecodeType
  static DecodeBarcodeType databarStackedOmniDirectional_ =
      DecodeBarcodeType._internal("DatabarStackedOmniDirectional");

  /// See DecodeType
  static DecodeBarcodeType databarStacked_ =
      DecodeBarcodeType._internal("DatabarStacked");

  /// See DecodeType
  static DecodeBarcodeType databarExpandedStacked_ =
      DecodeBarcodeType._internal("DatabarExpandedStacked");

  /// See DecodeType
  static DecodeBarcodeType compactPdf417_ =
      DecodeBarcodeType._internal("CompactPdf417");

  /// See DecodeType
  static DecodeBarcodeType gS1QR_ = DecodeBarcodeType._internal("GS1QR");

  /// See DecodeType
  static DecodeBarcodeType maxiCode_ = DecodeBarcodeType._internal("MaxiCode");

  /// See DecodeType
  static DecodeBarcodeType micrE13B_ = DecodeBarcodeType._internal("MicrE13B");

  /// See DecodeType
  static DecodeBarcodeType code32_ = DecodeBarcodeType._internal("Code32");

  /// See DecodeType
  static DecodeBarcodeType dataLogic2of5_ =
      DecodeBarcodeType._internal("DataLogic2of5");

  /// See DecodeType
  static DecodeBarcodeType dotCode_ = DecodeBarcodeType._internal("DotCode");

  /// See DecodeType
  static DecodeBarcodeType dutchKIX_ = DecodeBarcodeType._internal("DutchKIX");

  /// See DecodeType
  static DecodeBarcodeType codablockF_ =
      DecodeBarcodeType._internal("CodablockF");

  /// See DecodeType
  static DecodeBarcodeType mailmark_ = DecodeBarcodeType._internal("Mailmark");

  /// See DecodeType
  static DecodeBarcodeType gS1DotCode_ =
      DecodeBarcodeType._internal("GS1DotCode");

  /// See DecodeType
  static DecodeBarcodeType hIBCCode39LIC_ =
      DecodeBarcodeType._internal("HIBCCode39LIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCCode128LIC_ =
      DecodeBarcodeType._internal("HIBCCode128LIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCAztecLIC_ =
      DecodeBarcodeType._internal("HIBCAztecLIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCDataMatrixLIC_ =
      DecodeBarcodeType._internal("HIBCDataMatrixLIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCQRLIC_ =
      DecodeBarcodeType._internal("HIBCQRLIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCCode39PAS_ =
      DecodeBarcodeType._internal("HIBCCode39PAS");

  /// See DecodeType
  static DecodeBarcodeType hIBCCode128PAS_ =
      DecodeBarcodeType._internal("HIBCCode128PAS");

  /// See DecodeType
  static DecodeBarcodeType hIBCAztecPAS_ =
      DecodeBarcodeType._internal("HIBCAztecPAS");

  /// See DecodeType
  static DecodeBarcodeType hIBCDataMatrixPAS_ =
      DecodeBarcodeType._internal("HIBCDataMatrixPAS");

  /// See DecodeType
  static DecodeBarcodeType hIBCQRPAS_ =
      DecodeBarcodeType._internal("HIBCQRPAS");

  /// See DecodeType
  static DecodeBarcodeType hanXin_ = DecodeBarcodeType._internal("HanXin");

  /// See DecodeType
  static DecodeBarcodeType gS1HanXin_ =
      DecodeBarcodeType._internal("GS1HanXin");

  static dynamic encode(DecodeBarcodeType data) => data.value;

  String? toJson() => value;

  @override
  String toString() => value == null ? "null" : value.toString();
}

==> aspose_barcode_cloud-0.23.7.tar.gz: lib/model/decode_barcode_type.dart <==
part of aspose_barcode_cloud.api;

class DecodeBarcodeType {
  /// The underlying value of this enum member.
  String? value;

  DecodeBarcodeType._internal(this.value);

  /// See DecodeType
  static DecodeBarcodeType all_ = DecodeBarcodeType._internal("all");

  /// See DecodeType
  static DecodeBarcodeType australiaPost_ =
      DecodeBarcodeType._internal("AustraliaPost");

  /// See DecodeType
  static DecodeBarcodeType aztec_ = DecodeBarcodeType._internal("Aztec");

  /// See DecodeType
  static DecodeBarcodeType iSBN_ = DecodeBarcodeType._internal("ISBN");

  /// See DecodeType
  static DecodeBarcodeType codabar_ = DecodeBarcodeType._internal("Codabar");

  /// See DecodeType
  static DecodeBarcodeType code11_ = DecodeBarcodeType._internal("Code11");

  /// See DecodeType
  static DecodeBarcodeType code128_ = DecodeBarcodeType._internal("Code128");

  /// See DecodeType
  static DecodeBarcodeType gS1Code128_ =
      DecodeBarcodeType._internal("GS1Code128");

  /// See DecodeType
  static DecodeBarcodeType code39Extended_ =
      DecodeBarcodeType._internal("Code39Extended");

  /// See DecodeType
  static DecodeBarcodeType code39Standard_ =
      DecodeBarcodeType._internal("Code39Standard");

  /// See DecodeType
  static DecodeBarcodeType code93Extended_ =
      DecodeBarcodeType._internal("Code93Extended");

  /// See DecodeType
  static DecodeBarcodeType code93Standard_ =
      DecodeBarcodeType._internal("Code93Standard");

  /// See DecodeType
  static DecodeBarcodeType dataMatrix_ =
      DecodeBarcodeType._internal("DataMatrix");

  /// See DecodeType
  static DecodeBarcodeType deutschePostIdentcode_ =
      DecodeBarcodeType._internal("DeutschePostIdentcode");

  /// See DecodeType
  static DecodeBarcodeType deutschePostLeitcode_ =
      DecodeBarcodeType._internal("DeutschePostLeitcode");

  /// See DecodeType
  static DecodeBarcodeType eAN13_ = DecodeBarcodeType._internal("EAN13");

  /// See DecodeType
  static DecodeBarcodeType eAN14_ = DecodeBarcodeType._internal("EAN14");

  /// See DecodeType
  static DecodeBarcodeType eAN8_ = DecodeBarcodeType._internal("EAN8");

  /// See DecodeType
  static DecodeBarcodeType iATA2of5_ = DecodeBarcodeType._internal("IATA2of5");

  /// See DecodeType
  static DecodeBarcodeType interleaved2of5_ =
      DecodeBarcodeType._internal("Interleaved2of5");

  /// See DecodeType
  static DecodeBarcodeType iSSN_ = DecodeBarcodeType._internal("ISSN");

  /// See DecodeType
  static DecodeBarcodeType iSMN_ = DecodeBarcodeType._internal("ISMN");

  /// See DecodeType
  static DecodeBarcodeType italianPost25_ =
      DecodeBarcodeType._internal("ItalianPost25");

  /// See DecodeType
  static DecodeBarcodeType iTF14_ = DecodeBarcodeType._internal("ITF14");

  /// See DecodeType
  static DecodeBarcodeType iTF6_ = DecodeBarcodeType._internal("ITF6");

  /// See DecodeType
  static DecodeBarcodeType macroPdf417_ =
      DecodeBarcodeType._internal("MacroPdf417");

  /// See DecodeType
  static DecodeBarcodeType matrix2of5_ =
      DecodeBarcodeType._internal("Matrix2of5");

  /// See DecodeType
  static DecodeBarcodeType mSI_ = DecodeBarcodeType._internal("MSI");

  /// See DecodeType
  static DecodeBarcodeType oneCode_ = DecodeBarcodeType._internal("OneCode");

  /// See DecodeType
  static DecodeBarcodeType oPC_ = DecodeBarcodeType._internal("OPC");

  /// See DecodeType
  static DecodeBarcodeType patchCode_ =
      DecodeBarcodeType._internal("PatchCode");

  /// See DecodeType
  static DecodeBarcodeType pdf417_ = DecodeBarcodeType._internal("Pdf417");

  /// See DecodeType
  static DecodeBarcodeType microPdf417_ =
      DecodeBarcodeType._internal("MicroPdf417");

  /// See DecodeType
  static DecodeBarcodeType planet_ = DecodeBarcodeType._internal("Planet");

  /// See DecodeType
  static DecodeBarcodeType postnet_ = DecodeBarcodeType._internal("Postnet");

  /// See DecodeType
  static DecodeBarcodeType pZN_ = DecodeBarcodeType._internal("PZN");

  /// See DecodeType
  static DecodeBarcodeType qR_ = DecodeBarcodeType._internal("QR");

  /// See DecodeType
  static DecodeBarcodeType microQR_ = DecodeBarcodeType._internal("MicroQR");

  /// See DecodeType
  static DecodeBarcodeType rM4SCC_ = DecodeBarcodeType._internal("RM4SCC");

  /// See DecodeType
  static DecodeBarcodeType sCC14_ = DecodeBarcodeType._internal("SCC14");

  /// See DecodeType
  static DecodeBarcodeType sSCC18_ = DecodeBarcodeType._internal("SSCC18");

  /// See DecodeType
  static DecodeBarcodeType standard2of5_ =
      DecodeBarcodeType._internal("Standard2of5");

  /// See DecodeType
  static DecodeBarcodeType supplement_ =
      DecodeBarcodeType._internal("Supplement");

  /// See DecodeType
  static DecodeBarcodeType uPCA_ = DecodeBarcodeType._internal("UPCA");

  /// See DecodeType
  static DecodeBarcodeType uPCE_ = DecodeBarcodeType._internal("UPCE");

  /// See DecodeType
  static DecodeBarcodeType vIN_ = DecodeBarcodeType._internal("VIN");

  /// See DecodeType
  static DecodeBarcodeType pharmacode_ =
      DecodeBarcodeType._internal("Pharmacode");

  /// See DecodeType
  static DecodeBarcodeType gS1DataMatrix_ =
      DecodeBarcodeType._internal("GS1DataMatrix");

  /// See DecodeType
  static DecodeBarcodeType databarOmniDirectional_ =
      DecodeBarcodeType._internal("DatabarOmniDirectional");

  /// See DecodeType
  static DecodeBarcodeType databarTruncated_ =
      DecodeBarcodeType._internal("DatabarTruncated");

  /// See DecodeType
  static DecodeBarcodeType databarLimited_ =
      DecodeBarcodeType._internal("DatabarLimited");

  /// See DecodeType
  static DecodeBarcodeType databarExpanded_ =
      DecodeBarcodeType._internal("DatabarExpanded");

  /// See DecodeType
  static DecodeBarcodeType swissPostParcel_ =
      DecodeBarcodeType._internal("SwissPostParcel");

  /// See DecodeType
  static DecodeBarcodeType australianPosteParcel_ =
      DecodeBarcodeType._internal("AustralianPosteParcel");

  /// See DecodeType
  static DecodeBarcodeType code16K_ = DecodeBarcodeType._internal("Code16K");

  /// See DecodeType
  static DecodeBarcodeType databarStackedOmniDirectional_ =
      DecodeBarcodeType._internal("DatabarStackedOmniDirectional");

  /// See DecodeType
  static DecodeBarcodeType databarStacked_ =
      DecodeBarcodeType._internal("DatabarStacked");

  /// See DecodeType
  static DecodeBarcodeType databarExpandedStacked_ =
      DecodeBarcodeType._internal("DatabarExpandedStacked");

  /// See DecodeType
  static DecodeBarcodeType compactPdf417_ =
      DecodeBarcodeType._internal("CompactPdf417");

  /// See DecodeType
  static DecodeBarcodeType gS1QR_ = DecodeBarcodeType._internal("GS1QR");

  /// See DecodeType
  static DecodeBarcodeType maxiCode_ = DecodeBarcodeType._internal("MaxiCode");

  /// See DecodeType
  static DecodeBarcodeType micrE13B_ = DecodeBarcodeType._internal("MicrE13B");

  /// See DecodeType
  static DecodeBarcodeType code32_ = DecodeBarcodeType._internal("Code32");

  /// See DecodeType
  static DecodeBarcodeType dataLogic2of5_ =
      DecodeBarcodeType._internal("DataLogic2of5");

  /// See DecodeType
  static DecodeBarcodeType dotCode_ = DecodeBarcodeType._internal("DotCode");

  /// See DecodeType
  static DecodeBarcodeType dutchKIX_ = DecodeBarcodeType._internal("DutchKIX");

  /// See DecodeType
  static DecodeBarcodeType codablockF_ =
      DecodeBarcodeType._internal("CodablockF");

  /// See DecodeType
  static DecodeBarcodeType mailmark_ = DecodeBarcodeType._internal("Mailmark");

  /// See DecodeType
  static DecodeBarcodeType gS1DotCode_ =
      DecodeBarcodeType._internal("GS1DotCode");

  /// See DecodeType
  static DecodeBarcodeType hIBCCode39LIC_ =
      DecodeBarcodeType._internal("HIBCCode39LIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCCode128LIC_ =
      DecodeBarcodeType._internal("HIBCCode128LIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCAztecLIC_ =
      DecodeBarcodeType._internal("HIBCAztecLIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCDataMatrixLIC_ =
      DecodeBarcodeType._internal("HIBCDataMatrixLIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCQRLIC_ =
      DecodeBarcodeType._internal("HIBCQRLIC");

  /// See DecodeType
  static DecodeBarcodeType hIBCCode39PAS_ =
      DecodeBarcodeType._internal("HIBCCode39PAS");

  /// See DecodeType
  static DecodeBarcodeType hIBCCode128PAS_ =
      DecodeBarcodeType._internal("HIBCCode128PAS");

  /// See DecodeType
  static DecodeBarcodeType hIBCAztecPAS_ =
      DecodeBarcodeType._internal("HIBCAztecPAS");

  /// See DecodeType
  static DecodeBarcodeType hIBCDataMatrixPAS_ =
      DecodeBarcodeType._internal("HIBCDataMatrixPAS");

  /// See DecodeType
  static DecodeBarcodeType hIBCQRPAS_ =
      DecodeBarcodeType._internal("HIBCQRPAS");

  /// See DecodeType
  static DecodeBarcodeType hanXin_ = DecodeBarcodeType._internal("HanXin");

  /// See DecodeType
  static DecodeBarcodeType gS1HanXin_ =
      DecodeBarcodeType._internal("GS1HanXin");

  DecodeBarcodeType.fromJson(dynamic data) {
    switch (data) {
      case "all":
        value = data;
        break;
      case "AustraliaPost":
        value = data;
        break;
      case "Aztec":
        value = data;
        break;
      case "ISBN":
        value = data;
        break;
      case "Codabar":
        value = data;
        break;
      case "Code11":
        value = data;
        break;
      case "Code128":
        value = data;
        break;
      case "GS1Code128":
        value = data;
        break;
      case "Code39Extended":
        value = data;
        break;
      case "Code39Standard":
        value = data;
        break;
      case "Code93Extended":
        value = data;
        break;
      case "Code93Standard":
        value = data;
        break;
      case "DataMatrix":
        value = data;
        break;
      case "DeutschePostIdentcode":
        value = data;
        break;
      case "DeutschePostLeitcode":
        value = data;
        break;
      case "EAN13":
        value = data;
        break;
      case "EAN14":
        value = data;
        break;
      case "EAN8":
        value = data;
        break;
      case "IATA2of5":
        value = data;
        break;
      case "Interleaved2of5":
        value = data;
        break;
      case "ISSN":
        value = data;
        break;
      case "ISMN":
        value = data;
        break;
      case "ItalianPost25":
        value = data;
        break;
      case "ITF14":
        value = data;
        break;
      case "ITF6":
        value = data;
        break;
      case "MacroPdf417":
        value = data;
        break;
      case "Matrix2of5":
        value = data;
        break;
      case "MSI":
        value = data;
        break;
      case "OneCode":
        value = data;
        break;
      case "OPC":
        value = data;
        break;
      case "PatchCode":
        value = data;
        break;
      case "Pdf417":
        value = data;
        break;
      case "MicroPdf417":
        value = data;
        break;
      case "Planet":
        value = data;
        break;
      case "Postnet":
        value = data;
        break;
      case "PZN":
        value = data;
        break;
      case "QR":
        value = data;
        break;
      case "MicroQR":
        value = data;
        break;
      case "RM4SCC":
        value = data;
        break;
      case "SCC14":
        value = data;
        break;
      case "SSCC18":
        value = data;
        break;
      case "Standard2of5":
        value = data;
        break;
      case "Supplement":
        value = data;
        break;
      case "UPCA":
        value = data;
        break;
      case "UPCE":
        value = data;
        break;
      case "VIN":
        value = data;
        break;
      case "Pharmacode":
        value = data;
        break;
      case "GS1DataMatrix":
        value = data;
        break;
      case "DatabarOmniDirectional":
        value = data;
        break;
      case "DatabarTruncated":
        value = data;
        break;
      case "DatabarLimited":
        value = data;
        break;
      case "DatabarExpanded":
        value = data;
        break;
      case "SwissPostParcel":
        value = data;
        break;
      case "AustralianPosteParcel":
        value = data;
        break;
      case "Code16K":
        value = data;
        break;
      case "DatabarStackedOmniDirectional":
        value = data;
        break;
      case "DatabarStacked":
        value = data;
        break;
      case "DatabarExpandedStacked":
        value = data;
        break;
      case "CompactPdf417":
        value = data;
        break;
      case "GS1QR":
        value = data;
        break;
      case "MaxiCode":
        value = data;
        break;
      case "MicrE13B":
        value = data;
        break;
      case "Code32":
        value = data;
        break;
      case "DataLogic2of5":
        value = data;
        break;
      case "DotCode":
        value = data;
        break;
      case "DutchKIX":
        value = data;
        break;
      case "CodablockF":
        value = data;
        break;
      case "Mailmark":
        value = data;
        break;
      case "GS1DotCode":
        value = data;
        break;
      case "HIBCCode39LIC":
        value = data;
        break;
      case "HIBCCode128LIC":
        value = data;
        break;
      case "HIBCAztecLIC":
        value = data;
        break;
      case "HIBCDataMatrixLIC":
        value = data;
        break;
      case "HIBCQRLIC":
        value = data;
        break;
      case "HIBCCode39PAS":
        value = data;
        break;
      case "HIBCCode128PAS":
        value = data;
        break;
      case "HIBCAztecPAS":
        value = data;
        break;
      case "HIBCDataMatrixPAS":
        value = data;
        break;
      case "HIBCQRPAS":
        value = data;
        break;
      case "HanXin":
        value = data;
        break;
      case "GS1HanXin":
        value = data;
        break;
      default:
        throw Exception('Unknown enum value to decode: $data');
    }
  }

  static dynamic encode(DecodeBarcodeType data) {
    return data.value;
  }

  String? toJson() {
    return value;
  }

  String toString() {
    return value == null ? "null" : value.toString();
  }
}
